@@ -82,7 +82,7 @@ GnomeUIInfo gedit_file_menu[] =
 	
 	GNOMEUIINFO_ITEM_STOCK (N_("Open from _URI..."),
 			  N_("Open a file from a specified URI"),
-			  uri_open_cb,
+			  file_uri_open_cb,
 			  GNOME_STOCK_MENU_OPEN),
 /*	
 	GNOMEUIINFO_ITEM_STOCK (N_("Save _to URI..."),
@@ -152,7 +152,7 @@ GnomeUIInfo gedit_search_menu[] =
 		gedit_goto_line_cb, NULL, NULL,
 		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_JUMP_TO
 	},
-
+/*
 	GNOMEUIINFO_SEPARATOR,
 
 	{
@@ -162,7 +162,7 @@ GnomeUIInfo gedit_search_menu[] =
 		gedit_file_info_cb, NULL, NULL,
 		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_INDEX
 	},
-
+*/
 
 	GNOMEUIINFO_END
 };
